#[non_exhaustive]pub struct Flash<'a> { /* private fields */ }Expand description
FLASH peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl FLASH<'_>
impl FLASH<'_>
Sourcepub unsafe fn steal() -> FLASH<'_>
pub unsafe fn steal() -> FLASH<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> FLASH<'_>
pub unsafe fn clone_unchecked(&self) -> FLASH<'_>
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.